@@ -3,7 +3,7 @@
 
 package Games::Hack::Patch::i686;
 
-$VERSION=0.2;
+$VERSION=0.3;
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -20,7 +20,7 @@ sub GetNOP
   $binary="";
 
 ### Floating point store? Stores always %ST(0).
-  if ($disass =~ m#^f[bi]?st(p)? #)
+  if ($disass =~ m#^f[bi]?st(p)?s? #)
   {
     if ($1)
     {
